qpsphere documentation
======================

Qpsphere is a Python3 library that provides several methods
to extract refractive index and radius of spherical, dielectric
objects in quantitative phase imaging.
This is the documentaion of qpsphere version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   sec_introduction
   sec_getting_started
   sec_code_reference
   sec_bibliography


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
